Version 1.1.0
-------------

Released 2019-08-22

-   Indicate support for Python 2.7 and 3.5+.
-   Moved source to Git on GitHub because BitBucket removed Mercurial
    support.
-   Moved package metadata to ``setup.cfg`` with a placeholder
    ``setup.py``. Requires setuptools >= 30.3.0 to install sdist.
-   Moved to ``src`` directory layout.
-   Apply code style tools and pre-commit config.


Version 1.0.3
-------------

Released 2015-08-14

-   Move named args to ``kwargs`` to make them keyword-only.


Version 1.0.2
-------------

Released 2015-07-08

-   Remove keyword-only args syntax to support Python 2.


Version 1.0.1
-------------

Released 2015-01-29

-   Fix param numbering.


Version 1.0.0
-------------

Released 2015-01-27

-   Write new client using requests.


Version 0.2.0
-------------

Released 2015-01-27

-   Update official client.
-   Clean up code and support Python 2.6 and 3.3.


Version 0.1.0
-------------

Released 2014-01-28

-   Make official client installable.
